@@ -28,9 +28,9 @@ class Model(models.Model):
         - is_deleted as indicator that object is deleted or not;
      """
 
-    id = models.UUIDField(_('ID'), default=uuid.uuid4, primary_key=True)
-    created_at = models.DateTimeField(_('created at'), auto_now_add=True)
-    updated_at = models.DateTimeField(_('updated at'), auto_now=True)
+    id = models.UUIDField(_('ID'), default=uuid.uuid4, primary_key=True, editable=False)
+    created_at = models.DateTimeField(_('created at'), auto_now_add=True, editable=False)
+    updated_at = models.DateTimeField(_('updated at'), auto_now=True, editable=False)
     is_deleted = models.BooleanField(_('is deleted'), default=False)
 
     objects = Manager()
